@@ -1,5 +1,5 @@
 #
-# $Id: IpVersion.pm,v 1.1.2.12.2.2 2006/05/31 16:49:57 gomor Exp $
+# $Id: IpVersion.pm,v 1.1.2.14.2.2 2006/06/08 18:55:42 gomor Exp $
 #
 package Net::SinFP::DB::IpVersion;
 use strict;
@@ -15,9 +15,17 @@ our @AS = qw(
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
+our $Id     = $AS[0];
+our @Fields = @AS[1..$#AS];
+
+sub getIdIpVersion { shift->lookupId(ipVersion => shift)                    }
+sub getIpVersion   { shift->lookupString('ipVersion', idIpVersion => shift) }
+
+1;
+
 =head1 NAME
 
-Net::SinFP::DB::IpVersion - IpVersion SQL table
+Net::SinFP::DB::IpVersion - IpVersion database table
 
 =head1 DESCRIPTION
 
@@ -25,12 +33,6 @@ Go to http://www.gomor.org/sinfp to know more.
 
 =cut
 
-our $Id     = qw(idIpVersion);
-our @Fields = qw(ipVersion);
-
-sub getIdIpVersion { shift->lookupId(ipVersion => shift)                    }
-sub getIpVersion   { shift->lookupString('ipVersion', idIpVersion => shift) }
-
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
@@ -43,5 +45,3 @@ You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
 =cut
-
-1;
